==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/lt_LT.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privatumas",
    "-" : "-",
    "Add external admin" : "Pridėti išorinį administratorių",
    "Your files are not protected by encryption." : "Jūsų failai nėra apsaugoti šifravimu.",
    "The admin hasn't selected the location of the server yet." : "Administratorius kol kas nepasirinko serverio vietovės.",
    "Please select a country" : "Pasirinkite šalį",
    "You don't have any shares with individual users." : "Jūs neturite jokių viešinių su atskirais naudotojais.",
    "Afghanistan" : "Afganistanas",
    "Albania" : "Albanija",
    "Armenia" : "Armėnija",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austrija",
    "Australia" : "Australija",
    "Azerbaijan" : "Azerbaidžanas",
    "Bosnia and Herzegowina" : "Bosnija ir Hercegovina",
    "Bangladesh" : "Bangladešas",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Fasas",
    "Bulgaria" : "Bulgarija",
    "Burundi" : "Burundis",
    "Benin" : "Beninas",
    "Brunei" : "Brunėjus",
    "Bolivia" : "Bolivija",
    "Brazil" : "Brazilija",
    "Bahamas" : "Bahamos",
    "Bhutan" : "Butanas",
    "Botswana" : "Botsvana",
    "Belarus" : "Baltarusija",
    "Belize" : "Belizas",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Kongo Demokratinė Respublika",
    "Central African Republic" : "Centrinės Afrikos Respublika",
    "Congo" : "Kongas",
    "Switzerland" : "Šveicarija",
    "Cote d'Ivoire" : "Dramblio Kaulo Krantas",
    "Chile" : "Čilė",
    "Cameroon" : "Kamerūnas",
    "China" : "Kinija",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kosta Rika",
    "Cuba" : "Kuba",
    "Cyprus" : "Kipras",
    "Czech" : "Čekija",
    "Germany" : "Vokietija",
    "Djibouti" : "Džibutis",
    "Denmark" : "Danija",
    "Dominican Republic" : "Dominikos Respublika",
    "Algeria" : "Alžyras",
    "Ecuador" : "Ekvadoras",
    "Estonia" : "Estija",
    "Egypt" : "Egiptas",
    "West Sahara" : "Vakarų Sachara",
    "Eritrea" : "Eritrėja",
    "Spain" : "Ispanija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Suomija",
    "Fiji" : "Fidžis",
    "Falkland Islands" : "Folklando salos",
    "France" : "Prancūzija",
    "Gabon" : "Gabonas",
    "United Kingdom" : "Jungtinė Karalystė",
    "Georgia" : "Gruzija",
    "Ghana" : "Gana",
    "Greenland" : "Grenlandija",
    "Gambia" : "Gambija",
    "Guinea" : "Gvinėja",
    "Greece" : "Graikija",
    "Guatemala" : "Gvatemala",
    "Guinea-Bissau" : "Bisau Gvinėja",
    "Guyana" : "Gajana",
    "Honduras" : "Hondūras",
    "Croatia" : "Kroatija",
    "Haiti" : "Haitis",
    "Hungary" : "Vengrija",
    "Indonesia" : "Indonezija",
    "Ireland" : "Airija",
    "Israel" : "Izraelis",
    "India" : "Indija",
    "Iraq" : "Irakas",
    "Iran" : "Iranas",
    "Iceland" : "Islandija",
    "Italy" : "Italija",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanija",
    "Japan" : "Japonija",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizija",
    "Cambodia" : "Kambodža",
    "North Korea" : "Šiaurės Korėja",
    "South Korea" : "Pietų Korėja",
    "Kuwait" : "Kuveitas",
    "Kazakhstan" : "Kazachstanas",
    "Laos" : "Laosas",
    "Lebanon" : "Libanas",
    "Sri Lanka" : "Šri Lanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesotas",
    "Lithuania" : "Lietuva",
    "Luxembourg" : "Liuksemburgas",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Marokas",
    "Moldova" : "Moldova",
    "Montenegro" : "Juodkalnija",
    "Madagascar" : "Madagaskaras",
    "Mali" : "Malis",
    "Myanmar" : "Mianmaras",
    "Mongolia" : "Mongolija",
    "Mauritania" : "Mauritanija",
    "Malawi" : "Malavis",
    "Mexico" : "Meksika",
    "Malaysia" : "Malaizija",
    "Mozambique" : "Mozambikas",
    "Namibia" : "Namibija",
    "Niger" : "Nigeris",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nyderlandai",
    "Norway" : "Norvegija",
    "Nepal" : "Nepalas",
    "New Zealand" : "Naujoji Zelandija",
    "Oman" : "Omanas",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Naujoji Gvinėja",
    "Philippines" : "Filipinai",
    "Pakistan" : "Pakistanas",
    "Poland" : "Lenkija",
    "Portugal" : "Portugalija",
    "Paraguay" : "Paragvajus",
    "Russia" : "Rusija",
    "Sudan" : "Sudanas",
    "Sweden" : "Švedija",
    "Chad" : "Čadas",
    "Turkey" : "Turkija",
    "Ukraine" : "Ukraina",
    "South Africa" : "Pietų Afrika",
    "Your Nextcloud account" : "Jūsų Nextcloud paskyra",
    "Where is your data?" : "Kur yra jūsų duomenys?",
    "Administrators" : "Administratoriai",
    "People you shared with" : "Žmonės su kuriais bendrinote"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/lt_LT.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privatumas",
    "-" : "-",
    "Add external admin" : "Pridėti išorinį administratorių",
    "Your files are not protected by encryption." : "Jūsų failai nėra apsaugoti šifravimu.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Jūsų failai yra šifruoti naudojant {linkopen}serverio šifravimą ↗{linkclose}.",
    "Your data is located in: " : "Jūsų duomenų vieta yra čia: ",
    "The admin hasn't selected the location of the server yet." : "Administratorius kol kas nepasirinko serverio vietovės.",
    "Please select a country" : "Pasirinkite šalį",
    "You don't have any shares with individual users." : "Jūs neturite jokių viešinių su atskirais naudotojais.",
    "Somaliland" : "Somalilandas",
    "United Arab Emirates" : "Jungtiniai Arabų Emyratai",
    "Afghanistan" : "Afganistanas",
    "Albania" : "Albanija",
    "Armenia" : "Armėnija",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austrija",
    "Australia" : "Australija",
    "Azerbaijan" : "Azerbaidžanas",
    "Bosnia and Herzegowina" : "Bosnija ir Hercegovina",
    "Bangladesh" : "Bangladešas",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Fasas",
    "Bulgaria" : "Bulgarija",
    "Burundi" : "Burundis",
    "Benin" : "Beninas",
    "Brunei" : "Brunėjus",
    "Bolivia" : "Bolivija",
    "Brazil" : "Brazilija",
    "Bahamas" : "Bahamos",
    "Bhutan" : "Butanas",
    "Botswana" : "Botsvana",
    "Belarus" : "Baltarusija",
    "Belize" : "Belizas",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Kongo Demokratinė Respublika",
    "Central African Republic" : "Centrinės Afrikos Respublika",
    "Congo" : "Kongas",
    "Switzerland" : "Šveicarija",
    "Cote d'Ivoire" : "Dramblio Kaulo Krantas",
    "Chile" : "Čilė",
    "Cameroon" : "Kamerūnas",
    "China" : "Kinija",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kosta Rika",
    "Cuba" : "Kuba",
    "Cyprus" : "Kipras",
    "Czech" : "Čekija",
    "Germany" : "Vokietija",
    "Djibouti" : "Džibutis",
    "Denmark" : "Danija",
    "Dominican Republic" : "Dominikos Respublika",
    "Algeria" : "Alžyras",
    "Ecuador" : "Ekvadoras",
    "Estonia" : "Estija",
    "Egypt" : "Egiptas",
    "West Sahara" : "Vakarų Sachara",
    "Eritrea" : "Eritrėja",
    "Spain" : "Ispanija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Suomija",
    "Fiji" : "Fidžis",
    "Falkland Islands" : "Folklando salos",
    "France" : "Prancūzija",
    "Gabon" : "Gabonas",
    "United Kingdom" : "Jungtinė Karalystė",
    "Georgia" : "Gruzija",
    "Ghana" : "Gana",
    "Greenland" : "Grenlandija",
    "Gambia" : "Gambija",
    "Guinea" : "Gvinėja",
    "Equatorial Guinea" : "Pusiaujo Gvinėja",
    "Greece" : "Graikija",
    "Guatemala" : "Gvatemala",
    "Guinea-Bissau" : "Bisau Gvinėja",
    "Guyana" : "Gajana",
    "Honduras" : "Hondūras",
    "Croatia" : "Kroatija",
    "Haiti" : "Haitis",
    "Hungary" : "Vengrija",
    "Indonesia" : "Indonezija",
    "Ireland" : "Airija",
    "Israel" : "Izraelis",
    "India" : "Indija",
    "Iraq" : "Irakas",
    "Iran" : "Iranas",
    "Iceland" : "Islandija",
    "Italy" : "Italija",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanija",
    "Japan" : "Japonija",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizija",
    "Cambodia" : "Kambodža",
    "North Korea" : "Šiaurės Korėja",
    "South Korea" : "Pietų Korėja",
    "Kuwait" : "Kuveitas",
    "Kazakhstan" : "Kazachstanas",
    "Laos" : "Laosas",
    "Lebanon" : "Libanas",
    "Sri Lanka" : "Šri Lanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesotas",
    "Lithuania" : "Lietuva",
    "Luxembourg" : "Liuksemburgas",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Marokas",
    "Moldova" : "Moldova",
    "Montenegro" : "Juodkalnija",
    "Madagascar" : "Madagaskaras",
    "Macedonia" : "Makedonija",
    "Mali" : "Malis",
    "Myanmar" : "Mianmaras",
    "Mongolia" : "Mongolija",
    "Mauritania" : "Mauritanija",
    "Malawi" : "Malavis",
    "Mexico" : "Meksika",
    "Malaysia" : "Malaizija",
    "Mozambique" : "Mozambikas",
    "Namibia" : "Namibija",
    "New Caledonia" : "Naujoji Kaledonija",
    "Niger" : "Nigeris",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nyderlandai",
    "Norway" : "Norvegija",
    "Nepal" : "Nepalas",
    "New Zealand" : "Naujoji Zelandija",
    "Oman" : "Omanas",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Naujoji Gvinėja",
    "Philippines" : "Filipinai",
    "Pakistan" : "Pakistanas",
    "Poland" : "Lenkija",
    "Puerto Rico" : "Puerto Rikas",
    "Portugal" : "Portugalija",
    "Paraguay" : "Paragvajus",
    "Qatar" : "Kataras",
    "Romania" : "Rumunija",
    "Serbia" : "Serbija",
    "Russia" : "Rusija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudo Arabija",
    "Solomon Islands" : "Saliamono salos",
    "Sudan" : "Sudanas",
    "Sweden" : "Švedija",
    "Singapore" : "Singapūras",
    "Slovenia" : "Slovėnija",
    "Slovakia" : "Slovakija",
    "Sierra Leone" : "Siera Leonė",
    "Senegal" : "Senegalas",
    "Somalia" : "Somalis",
    "Suriname" : "Surinamas",
    "South Sudan" : "Pietų Sudanas",
    "El Salvador" : "El Salvadoras",
    "Syria" : "Sirija",
    "Swaziland" : "Svazilandas",
    "Chad" : "Čadas",
    "Togo" : "Togas",
    "Thailand" : "Tailandas",
    "Tajikistan" : "Tadžikistanas",
    "Timor-Leste" : "Rytų Timoras",
    "Turkmenistan" : "Turkmėnistanas",
    "Tunisia" : "Tunisas",
    "Turkey" : "Turkija",
    "Trinidad and Tobago" : "Trinidadas ir Tobagas",
    "Taiwan" : "Taivanas",
    "Tanzania" : "Tanzanija",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States" : "Jungtinės Amerikos Valstijos",
    "Uruguay" : "Urugvajus",
    "Uzbekistan" : "Uzbekistanas",
    "Venezuela" : "Venesuela",
    "Vietnam" : "Vietnamas",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemenas",
    "South Africa" : "Pietų Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabvė",
    "Your Nextcloud account" : "Jūsų Nextcloud paskyra",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Jūsų duomenys atvaizduoja kas jūs esate ir gali būti lengvai netinkamai panaudoti. Mes, Nextcloud, tikime, kad jūs turite teisę spręsti kas nutiks su jūsų duomenimis. Nextcloud apsaugo jūsų teises kaip tai yra apibrėžta Naudotojo Duomenų Manifeste!",
    "User Data Manifesto 2.0" : "Naudotojo Duomenų Manifestas 2.0",
    "Knowledge" : "Žinios",
    "of how the data is stored" : "apie tai, kaip yra saugomi duomenys",
    "Freedom" : "Laisvė",
    "to choose a platform" : "pasirinkti platformą",
    "Learn more ↗" : "Sužinokite daugiau ↗",
    "Where is your data?" : "Kur yra jūsų duomenys?",
    "Who has access to your data?" : "Kas turi prieigą prie jūsų duomenų?",
    "Administrators" : "Administratoriai",
    "People you shared with" : "Žmonės su kuriais bendrinote",
    "Privacy policy" : "Privatumo politika",
    "Read the privacy policy." : "Skaitykite privatumo politiką.",
    "Encryption" : "Šifravimas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
